/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *      ParamValue.hxx
 *
 *      Authors: Paolo Badino <paolo.badino@cern.ch>
 *      Version info: $Id: $
 *      Release: $Name:  $
 *
 *      Revision history:
 *      $Log: $
 *
 */
#ifndef GLITE_DATA_CONF_SERVICE_PARAMVALUE_HXX_
#define GLITE_DATA_CONF_SERVICE_PARAMVALUE_HXX_

#include "glite/data/config/service/ComponentConfiguration.hxx"
#include <string>

namespace glite {
namespace config{
  
/**
 * Configuration Parameters Single Value
 */
class ParamValue : public ComponentConfiguration::Param{
public:

    /**
     * ParamValue Type
     */
    static const char * TYPE;
    
    /**
     * Returns Param Type
     * @return Param Type
     */
    virtual const char * getType() const {return TYPE;}

    /**
     * Returns Param Value
     * @return Param Value
     */
    const std::string& getValue() const {return _value;}

    /**
     * Constructor
     * @param name [IN] the name of the Configuration Parameter
     * @param value [IN] the value of the Configuration Parameter
     */
    ParamValue(const char * name,const char * value):Param(name),_value(value){}

    /**
     * Destructor
     */
    virtual ~ParamValue(){}
    
private:
    /**
     * Default Constructor
     * Not Implemented
     */
    ParamValue();
    
private:
    /**
     * The Parameter SingleValue
     */
    std::string _value;        
};


} // End namespace config
} // End namespace glite

#endif //GLITE_DATA_CONF_SERVICE_PARAMVALUE_HXX_
