/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004-2008.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  Requirements, changes, info for this class (not complete list...):
 *
 *  bug #58470: FTS: make syslog facility configurable
 *     (https://savannah.cern.ch/bugs/?58470)
 *
 *  Authors: Zsolt Molnar <zsolt.molnar@cern.ch - http://www.zsoltmolnar.hu>
 *  Version info: $Id: SysLogFacility.h,v 1.1 2009/12/03 17:18:01 molnarzs Exp $
 *  Release: $Name:  $
 *
 */
#ifndef GLITE_DATA_CONF_SERVICE_SYSLOGFACILITY_H_
#define GLITE_DATA_CONF_SERVICE_SYSLOGFACILITY_H_

#include "SysLog.hxx"
#include <map>

namespace glite {
namespace config {

/** A system log with a configurable facility (like LOG_DAEMON, etc.) */
class SysLogFacilityBase : public SysLog
{
public:
    /** Enable logging on system log and configure a system log category.
     * NOTE: configuring system log appenders inside code for compliancy with
     * "Middleware Security Audit Logging Guidelines" document. The process id
     * is needed as part of the message after the logger name and log4cpp does
     * not have a format specifier for it.
     */
    static void EnableSystemLog();

protected:
    /** Constructor
     * @param fileLog [IN] flag to determine if logging on file must be enabled
     */
    SysLogFacilityBase(bool fileLog);
};

template <bool DefaultFileLog> class SysLogFacility : public SysLogFacilityBase
{
public:
    SysLogFacility(bool fileLog = DefaultFileLog)
        : SysLogFacilityBase(fileLog)
    {
        // EMPTY
    }
};

} // namespace config
} // namespace glite

#endif // GLITE_DATA_CONF_SERVICE_SYSLOGFACILITY_H_
