/**
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  Common Functions for the GLite Data Conf Service  module
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>, Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: Echo.cxx,v 1.1 2008/01/24 08:43:43 ptedesco Exp $
 *  Release: $Name:  $
 *
 */
#include "Echo.hxx"
#include <stdarg.h>
#include <stdio.h>

#define TEXT_RESET      0
#define TEXT_BLACK      30
#define TEXT_RED        31
#define TEXT_GREEN      32
#define TEXT_YELLOW     33
#define TEXT_BLUE       34
#define TEXT_MAGENTA    35
#define TEXT_CYAN       36
#define TEXT_WHITE      37

namespace {
bool  g_echo_enabled          = true;
bool  g_debug_enabled         = false;

void textcolor(int color) { 
    char command[13];
    // Command is the control command to the terminal
    sprintf(command, "%c[%d;%d;%dm", 0x1B, 0, 0, color);
    printf("%s", command);
}

} // namespace

namespace glite {
namespace config{

/**
 * echo_enabled
 * 
 * Enable/Disable echo
 */
void echo_enabled(bool b){
    g_echo_enabled = b;
}

/**
 * debug_enabled
 * enable/disable debug message
 */
void debug_enabled(bool b){
    g_debug_enabled = b;
}

/**
 * echo_action
 * Echo an Action Message
 */ 
void echo_action(const char * str){
    if(true == g_echo_enabled){ 
        fprintf(stdout,"%-60s",str);
        fflush(stdout);
    }
}

/**
 * echo_debug
 * Echo a debug message
 * @param fmt [IN] format string for the debug message to echo
 * @param ... [IN] message arguments
 */
void echo_debug(const char * fmt,...){
    if (g_echo_enabled && g_debug_enabled){
        va_list args;
        va_start(args,fmt);
        vfprintf(stdout,fmt,args);
        fprintf(stdout,"\n");
        va_end(args);
    }
}

/**
 * echo_message
 * Echo a Message
 */
void echo_message(const char * str){
    if(true == g_echo_enabled){ 
        fprintf(stdout,"%s\n",str);
    }
}

/**
 * echo_result
 * 
 * Echo a Message
 */
void echo_result(const char * result, int color){
    if(true == g_echo_enabled){ 
        fprintf(stdout,"[");
        textcolor(color);
        fprintf(stdout,result);
        textcolor(TEXT_RESET);
        fprintf(stdout,"]\n");
    }
}

/**
 * echo_success
 * Echo a Success Result
 */
void echo_success(){
    echo_result("  OK  ",TEXT_GREEN);
}

/**
 * echo_failure
 * Echo a Failure Result
 */
void echo_failure(){
    echo_result("FAILED",TEXT_RED);
}

/**
 * echo_warning
 * Echo a Warning Result
 */
void echo_warning(){
    echo_result("WARNING",TEXT_YELLOW);
}

} // End namespace config
} // End namespace glite
