/**
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  Common Functions for the GLite Data Config Service  module
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>, Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: Echo.hxx,v 1.1 2008/01/24 08:43:44 ptedesco Exp $
 *  Release: $Name:  $
 */
#ifndef GLITE_DATA_CONFIG_ECHO_HXX_ 
#define GLITE_DATA_CONFIG_ECHO_HXX_

#include <string>

namespace glite {
namespace config{

/**
 * echo_enabled
 * Enable/Disable echoing
 * @param b [IN] ture if echoing should be enabled, false otherwise
 */
void echo_enabled(bool b);

/**
 * debug_enabled
 * enable/disable debug messages
 */
void debug_enabled(bool b);

/**
 * echo_debug
 * Echo a debug message
 * @param fmt [IN] format string for the debug message to echo
 * @param ... [IN] message arguments
 */
void echo_debug(const char * fmt,...) 
    __attribute__((format(printf,1,2)));

/**
 * echo_action
 * Echo an Action Message
 * @param str [IN] the action message to echo
 */
void echo_action(const char * str);

/**
 * echo_message
 * Echo a Message
 * @param str [IN] the message to echo
 */
void echo_message(const char * str);

/**
 * echo_success
 * Echo a Success Result Message 
 */
void echo_success();

/**
 * echo_failure
 * Echo a Failute Result Message
 * @return 0
 */
void echo_failure();

/**
 * echo_warning
 * Echo a Warning Result Message
 * @return 0
 */
void echo_warning();

} // End namespace config
} // End namespace glite

#endif //GLITE_DATA_CONFIG_ECHO_HXX_
