/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *      ServiceConfiguration.cxx
 *
 *      Authors: Paolo Badino <paolo.badino@cern.ch>
 *      Version info: $Id: ServiceConfiguration.cxx,v 1.3 2009/10/29 10:22:44 szamsu Exp $
 *      Release: $Name:  $
 *
 *      Revision history:
 *      $Log: ServiceConfiguration.cxx,v $
 *      Revision 1.3  2009/10/29 10:22:44  szamsu
 *      Amending the last commit for bug#56533 by updates from Adrian Stelmaszyk <adisan@man.poznan.pl>
 *
 *      Revision 1.2  2008/01/24 08:43:44  ptedesco
 *      Fixed bug 28272
 *
 *      Revision 1.1.1.1  2004/08/18 15:52:41  badino
 *      Import of Module GLite Data config Service v.0.0
 *
 *
 */

#include "glite/data/config/service/ServiceConfiguration.hxx"
#include <stdio.h>
#include <signal.h>
#include <sys/wait.h>
#include <unistd.h>

using namespace glite::config;

namespace glite{
    namespace config{
         void *service_main(void * data);
    }
}


/**
 * Start the Component
 */
int ServiceConfiguration::start(){

    // Wait the Main Thread Is Started
    sem_init(&_synch,0,0);
    pthread_create(&_tid, NULL, service_main,this); 
    sem_wait(&_synch);
    
    return 0;
}

/**
 * Stop the Component
 */
int ServiceConfiguration::stop(){
    // Set run Flag
    this->svc_stop();
    
    // Wait Thread is finished
    pthread_join(_tid, 0);
    
    return 0;
}


/**
 * Do doLoop
 */
void ServiceConfiguration::run(){
    // Post The Semaphore
    sem_post(&_synch);
    
    // Invoke The Service Mai Method
    this->svc();
}
   
/**
 * Module Main Function
 */
void *glite::config::service_main(void * data){
    
    ServiceConfiguration * service = reinterpret_cast<ServiceConfiguration *>(data);
    service->run();
    
    return 0;
}
