/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004-2008.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  Authors: Zsolt Molnar <zsolt.molnar@cern.ch - http://www.zsoltmolnar.hu>
 *  Version info: $Id: SysLogFacility.cpp,v 1.1 2009/12/03 17:18:01 molnarzs Exp $
 *  Release: $Name:  $
 *
 */
#include <glite/data/config/service/SysLogFacility.h>
#include <glite/data/config/service/SysLogInfo.h>
#include "base-utils.hxx"
#include <log4cpp/SyslogAppender.hh>
#include <log4cpp/PatternLayout.hh>
#include <log4cpp/Category.hh>
#include <boost/assign/list_of.hpp>
#include <boost/lexical_cast.hpp>
#include <syslog.h>

namespace glite {
namespace config {

using namespace glite::config::xmlutils;

SysLogFacilityBase::SysLogFacilityBase(bool fileLog)
    : SysLog(
        SysLogInfo::instance().getIdent(),
        SysLogInfo::instance().getFacilityName(),
        fileLog)
{
    // EMPTY
}

void SysLogFacilityBase::EnableSystemLog()
{
    log4cpp::SyslogAppender * appender = 0;
    log4cpp::PatternLayout * layout = 0;
    try{
        const std::string& category = SysLogInfo::instance().getIdent();
        // NOTE : log4cpp does not provide a format argument for the process id, so it's
        // necessary to set it in the conversion pattern here.
        log4cpp::Category& syslog = log4cpp::Category::getInstance(category);
        // remove previous appenders
        syslog.setAdditivity(false);
        syslog.removeAllAppenders();
        // create sys log appender
        appender = new log4cpp::SyslogAppender(
            category, // appender name
            SysLogInfo::instance().serviceId(), // syslog name
            SysLogInfo::instance().getFacility());  // facility
        layout = new log4cpp::PatternLayout();
        // NOTE: *don't* add a space before %m in the pattern
        layout->setConversionPattern(SysLog::FormatString);
        appender->setLayout(layout);
        layout = 0;
        syslog.addAppender(appender);
        appender = 0;
    } catch (...){
        if (0 != layout) delete layout;
        if (0 != appender) delete appender;
        throw;
    }
}

} // namespace config
} // namespace glite
