/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004-2008.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *           Zsolt Molnar <zsolt.molnar@cern.ch - http://www.zsoltmolnar.hu>
 *  Version info: $Id: SysLogInfo.cxx,v 1.4 2009/12/11 17:51:35 molnarzs Exp $
 *  Release: $Name:  $
 *
 */

#include <glite/data/config/service/SysLogInfo.h>
#include <map>
#include <log4cpp/Category.hh>
#include <sstream>

using namespace glite::config;

SysLogInfo& SysLogInfo::instance()
{
    static SysLogInfo s_instance;
    return s_instance;
}

void SysLogInfo::reconfigure(
    const std::string& serviceName,
    const std::string& syslogIdent,
    const int syslogFacility,
    const std::string& syslogFacilityName)
{
    m_serviceName = serviceName;
    m_syslogIdent = syslogIdent;
    std::stringstream id;
    id << m_syslogIdent << "[" << m_pid << "]";
    m_serviceId = id.str();
    m_syslogFacility = syslogFacility;
    m_syslogFacilityName = syslogFacilityName;
    m_configured = true;
}

void SysLogInfo::configure(
    const std::string& serviceName,
    const std::string& syslogIdent,
    const int syslogFacility,
    const std::string& syslogFacilityName)
{
    if (!m_configured)
        reconfigure(serviceName, syslogIdent, syslogFacility, syslogFacilityName);
}

SysLogInfo::SysLogInfo()
    : m_configured(false),
      m_pid(getpid()),
      m_syslogFacility(-1)
{
    // EMPTY
}

int SysLogInfo::getFacility() const
{
    return m_syslogFacility;
}

const std::string& SysLogInfo::getIdent() const
{
    return m_syslogIdent;
}

const std::string& SysLogInfo::getFacilityName() const
{
    return m_syslogFacilityName;
}
