/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004-2008.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SysLogValidator
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: SysLogValidator.cxx,v 1.2 2008/07/02 08:25:41 ptedesco Exp $
 *  Release: $Name:  $
 *
 */

#include "SysLogValidator.hxx"
#include <sstream>

using namespace glite::config;

namespace {
    // hex-escape characters outside allowed range
    char hex[] = {
        '0','1','2','3',
        '4','5','6','7',
        '8','9','a','b',
        'c','d','e','f'
    };
}

/**
 * Singleton instance
 * @return singleton instance
 */
SysLogValidator& SysLogValidator::instance(){
    static SysLogValidator s_instance;
    return s_instance;
}

/**
 * validate_event_name
 */
void SysLogValidator::validate_event_name(const std::string& in,std::string& out){
    boost::match_results<std::string::const_iterator> what;
    boost::match_flag_type flags = boost::match_default;
    std::string::const_iterator s = in.begin();
    std::string::const_iterator e = in.end();
    if (regex_search(s,e,what,m_event_validator,flags)){
        out = what[0];
    }
}

/**
 * validate_name
 */
std::string SysLogValidator::validate_name(const std::string& in){
    std::string ret;
    boost::match_results<std::string::const_iterator> what;
    boost::match_flag_type flags = boost::match_default;
    std::string::const_iterator s = in.begin();
    std::string::const_iterator e = in.end();
    if (regex_search(s,e,what,m_name_validator,flags)){
        ret = what[0];
    }
    return ret;
}

/**
 * validate_value
 */
std::string SysLogValidator::validate_value(const std::string& in){
    std::string out;
    out.reserve(3 * in.length());
    for (std::string::const_iterator it = in.begin();it != in.end();++it){
        char c = (*it);
        if (c == '\\' || c== '%' || c == '"'){
            // escape character
            out.push_back('\\');
            out.push_back(c);
        } else if (c < (char)32 || c > 126){
            // character outside allowed range
            char c1 = c & 0x0F;
            char c2 = (c & 0xF0) >> 4;
            out.push_back('%');
            out.push_back(hex[(int)c2]);
            out.push_back(hex[(int)c1]);
        } else {
            out.push_back(c);
        }
    }
    return out;
}

/**
 * Constructor
 */
SysLogValidator::SysLogValidator() : 
    // any number of underscore/letter/dot in any position and numbers not at the beginning
    m_event_validator("[_a-zA-Z\\.][_a-zA-Z0-9\\.]*"),
    // any number of underscore/letter in any position and numbers not at the beginning
    m_name_validator("[_a-zA-Z][_a-zA-Z0-9]*"){
}

