/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004-2008.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SysLogValidator
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: SysLogValidator.hxx,v 1.2 2008/07/02 08:25:41 ptedesco Exp $
 *  Release: $Name:  $
 *
 */
#ifndef GLITE_DATA_CONF_SERVICE_SYSLOGVALIDATOR_HXX_
#define GLITE_DATA_CONF_SERVICE_SYSLOGVALIDATOR_HXX_

#include <boost/regex.hpp>
#include <string>

namespace glite {
namespace config {
    
/**
 * SysLogValidator
 * Utility for names and values validation
 */
class SysLogValidator{
public:
    
    /**
     * Singleton instance
     * @return singleton instance
     */
    static SysLogValidator& instance();
    
    /**
     * validate_event_name
     * validate the name of an event (java class name), e.g:
     * "a.b"    -> "a.b"
     * "  a.b"  -> "a.b"
     * "a.b2"   -> "a.b2"
     * "2a.b"   -> "a.b"
     * "a.b  c" -> "a.b"
     * @param in [IN] the event name
     * @param out [OUT] the validated event name
     */
    void validate_event_name(const std::string& in,std::string& out);
    
    /**
     * validate_name
     * validate a name for a key-value pair, e.g:
     * "a.b"    -> "a"
     * "  a"    -> "a"
     * "a2"     -> "a2"
     * "2a"     -> "a"
     * "a b"    -> "a"
     * @param in [IN] the name
     * @return the validated name
     */
    std::string validate_name(const std::string& in);
        
    /**
     * validate_value
     * escape '\', '%' and '"' adding a '\' before; 
     * @param in [IN] the value
     * @return the validated value
     */
    std::string validate_value(const std::string& in);
    
private:
    
    /**
     * Constructor
     */
    SysLogValidator();
    
    // regex objects for strings validation
    boost::regex m_event_validator;
    boost::regex m_name_validator;
};

} // namespace config
} // namespace glite

#endif // GLITE_DATA_CONF_SERVICE_SYSLOGVALIDATOR_HXX_


