/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Conf Service ConfigGenerator : Component.hxx
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id:  $
 *  Release: $Name:  $
 *
 *  Revision history:
 *  $Log: $
 *  
 */
 
#ifndef GLITE_DATA_CONFIG_SERVICE_CONFIG_GENERATOR_COMPONENT_HXX_ 
#define GLITE_DATA_CONFIG_SERVICE_CONFIG_GENERATOR_COMPONENT_HXX_

#include "Param.hxx"
#include <string>
#include <list>


namespace glite    {
namespace config   {
namespace generator{

class Component{
public:

    typedef std::list<std::string>  StringList;
    typedef std::list<Param*>       Params;

    /**
     * Constructor
     */
    Component(const char * name):_name(name){}

    /**
     * Destructor
     */
    ~Component(){
        Params::const_iterator it;
        for(it = _initParams.begin(); it != _initParams.end(); it++){
            delete (*it);
        }
        for(it = _configParams.begin(); it != _configParams.end(); it++){
            delete (*it);
        }
    }

    /**
     * Returns Component's Name
     */
    const char * getName() const {return _name.c_str();}

    /**
     * Returns Component's Library Name
     */
    const char * getLibrary() const {return _library.c_str();}
    /**
     * Set Component's Library Name
     */
    void setLibrary(const char * library){_library = library;}
    
    /**
     * Returns Component's Description
     */
    const char * getDescription() const {return _description.c_str();}
    /**
     * Set Component's Description
     */
    void setDescription(const char * description){_description = description;}

    /**
     * Returns Component's Dependencies
     */
    const StringList& getDependencies() const {return _dependencies;}
    /**
     * Set Component's Dependencies
     */
    void setDependencies(const StringList& dependencies){_dependencies = dependencies;}
    
    /**
     * Returns Component's Initialization Parameters
     */
    Params& getInitParams() {return _initParams;}
    
    /**
     * Returns Component's Configuration Parameters
     */
    Params& getConfigParams() {return _configParams;}
    
private: 
    
    /**
     * Component's Name
     */
    std::string _name;    

    /**
     * Component's Library
     */
    std::string _library;    

    /**
     * Component's Description
     */
    std::string _description;    
    
    /**
     * Component's Dependencies
     */
    StringList _dependencies;
    
    /**
     * Initailization Parameters
     */
    Params     _initParams;

    /**
     * Configuration Parameters
     */
    Params     _configParams;
};   


} // End namespace generator
} // End namespace config
} // End namespace glite


#endif //GLITE_DATA_CONFIG_SERVICE_CONFIG_GENERATOR_COMPONENT_HXX_
