/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Conf Service ConfigGenerator : ConsoleInputHandler.hxx
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id:  $
 *  Release: $Name:  $
 *
 *  Revision history:
 *  $Log: $
 *  
 */
 
#ifndef GLITE_DATA_CONFIG_SERVICE_CONFIG_GENERATOR_CONSOLEINPUTHANDLER_HXX_ 
#define GLITE_DATA_CONFIG_SERVICE_CONFIG_GENERATOR_CONSOLEINPUTHANDLER_HXX_ 

#include "InputHandler.hxx"

namespace log4cpp{
    class Category;
}

namespace glite    {
namespace config   {
namespace generator{

class ConsoleInputHandler : public InputHandler{
public:

    /**
     * Comstructor
     */
    ConsoleInputHandler(int level = -1);

    /**
     * Get the Configuration Values for the Service
     */
    virtual int getValues(Service * service);
    
    /**
     * Get the Logging Configuration Values for the Service
     */
    virtual int getLogValues(Service * service, LogGenerator * log);
    
private:

    /**
     * Read Parameter Value
     */
    void setParameterValue(Param * param);

    /**
     * Check if the parameter required configuration
     */
    bool includeParam(Param * param, bool mandatory_only, bool advanced_mode, bool expert_mode);

private:

    /**
     * The Logger
     */
    class log4cpp::Category& _logger;
        
    /**
     * the Detail level
     */
    int _level;
    
    bool _mandatoryOnly;
    bool _advancedMode;
    bool _expertMode;
};


} // End namespace generator
} // End namespace config
} // End namespace glite


#endif //GLITE_DATA_CONFIG_SERVICE_CONFIG_GENERATOR_CONSOLEINPUTHANDLER_HXX_
