/**
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Conf Service ConfigGenerator : LogGenerator.cxx
 *
 *  Authors:    Paolo Badino <paolo.badino@cern.ch>
 *              Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: LogGenerator.cxx,v 1.9 2008/07/02 08:25:41 ptedesco Exp $
 *  Release: $Name:  $
 *
 */
#include "LogGenerator.hxx"
#include <iostream>
#include <fstream>

#include "log4cpp/Category.hh"

using namespace log4cpp;
using namespace glite::config::generator;

namespace {
const char * DEFAULT_PRIORITY = "INFO";
const char * TEMP_DIR         = "/tmp/";
const char * DEFAULT_ROLLING  = false;    
}
/*
 * Service
 * 
 * Constructor
 */
LogGenerator::LogGenerator():_logger(Category::getInstance("glite-config-generator")),
    _logFileNameSet(false),
    _priority(DEFAULT_PRIORITY),
    _prioritySet(false),
    _rollFile(DEFAULT_ROLLING){
}

/*
 * ~Service
 * 
 * Destructor
 */
LogGenerator::~LogGenerator(){
}

/*
 * generate
 * 
 * Generate the Configuration for the given service
 */
int LogGenerator::generate(const char * out_name){
    
    std::string filename;
    if(0 == out_name){
        filename = _serviceName + ".log-properties";
    } else {
        filename = out_name;
    } 
    
    if(true == _logFileName.empty()){
        if(false == _serviceName.empty()){
            std::string fileName = (std::string)TEMP_DIR + _serviceName  + ".log";
            setLogFileName(fileName.c_str()); 
        } else {
            Category::getInstance("glite-config-generator").error("Destination LogFile Name unset");
            return -1;
        }
    }
    
    std::ofstream outfile;
    outfile.open(filename.c_str());
    if(outfile.is_open()){
        return writeLogProperties(outfile);
    } else {
        return -1;
    }
}

/* NOTE: since log4cpp does not offer a format character for the process id, it 
 * is not worth configuring the system log destinations in the configuration 
 * file - the appenders should be anyway removed and recreated at runtime.
 */

/*
 * writeLogProperties
 * 
 * Write Log Properties to output
 */
int LogGenerator::writeLogProperties(std::ostream& output){

    // categories
    output << "rootCategory=" << _priority.c_str() <<", file" << std::endl;
#if 0    
    output << "syslog-daemon=" << _priority.c_str() <<", syslog_daemon" << std::endl;
    output << "syslog-authpriv=" << _priority.c_str() <<", syslog_authpriv" << std::endl;
#endif    
    output << std::endl;
    
    // stdout appender
    output << "appender.stdout=ConsoleAppender" << std::endl;
    output << "appender.stdout.layout=PatternLayout" << std::endl;
    output << "appender.stdout.layout.ConversionPattern=%m%n" << std::endl;
    output << std::endl;
    
    // file appender
    if(true == _rollFile){
        output << "appender.file=RollingFileAppender" << std::endl;
    } else {
        output << "appender.file=FileAppender" << std::endl;
    }
    output << "appender.file.fileName=" << _logFileName.c_str() << std::endl;
    if(true == _rollFile){
        output << "appender.file.maxFileSize=10485760" << std::endl;
    }
    output << "appender.file.layout=PatternLayout" << std::endl;
    output << "appender.file.layout.ConversionPattern=%d %-6p %c - %m%n" << std::endl;
    output << std::endl;

#if 0    
    // syslog_daemon appender
    output << "appender.syslog_daemon=LocalSyslogAppender" << std::endl;
    output << "appender.syslog_daemon.facility=3" << std::endl; // LOG_DAEMON
    output << "appender.syslog_daemon.layout=PatternLayout" << std::endl;
    output << "appender.syslog_daemon.layout.ConversionPattern=" << _serviceName << "[-1]: " << SysLog::FormatString << std::endl;

    // syslog_authpriv appender
    output << "appender.syslog_authpriv=LocalSyslogAppender" << std::endl;
    output << "appender.syslog_authpriv.facility=10" << std::endl; // LOG_AUTHPRIV
    output << "appender.syslog_authpriv.layout=PatternLayout" << std::endl;
    output << "appender.syslog_authpriv.layout.ConversionPattern=" << _serviceName << "[-1]: " << SysLog::FormatString << std::endl;
#endif    
        
    return 0;
}
