/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Conf Service ConfigGenerator : LogGenerator.hxx
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id:  $
 *  Release: $Name:  $
 *
 *  Revision history:
 *  $Log: $
 *  
 */
 
#ifndef GLITE_DATA_CONFIG_SERVICE_CONFIG_GENERATOR_LOGGENERATOR_HXX_ 
#define GLITE_DATA_CONFIG_SERVICE_CONFIG_GENERATOR_LOGGENERATOR_HXX_

#include "Service.hxx"
#include <string>

namespace log4cpp{
    class Category;
}

namespace glite    {
namespace config   {
namespace generator{

class LogGenerator{
public:

    /**
     * Constructor
     */
    LogGenerator();

    /**
     * Destructor
     */
    ~LogGenerator();

    /**
     * set ServiceName Property
     */
    void setServiceName(const char * name) {_serviceName = name;}

    /**
     * set LogFileName Property
     */
    void setLogFileName(const char * file_name) {_logFileNameSet = true;_logFileName = file_name;}

    /**
     * Is LogFileName Property Set?
     */
    bool isLogFileNameSet() const {return _logFileNameSet;}

    /**
     * set Log Priority Property
     */
    void setPriority(const char * priority) {_prioritySet = true;_priority = priority;}

    /**
     * Is Priority Property Set?
     */
    bool isPrioritySet() const {return _prioritySet;}
    
    /**
     * set Roll Log File Property
     */
    void setRollFile(bool do_roll) {_rollFile = do_roll;}
    
    /**
     * Generate the Logging Configuration for the given service
     * @param out_name [IN] the Output File Name. If 0, the default name will be
     * used 
     * @return 0 if success, -1 otherwise
     */
    int generate(const char * out_name);
    
private:

    /**
     * Serialize Components
     */                     
    int writeLogProperties(std::ostream& output);
    
private: 

    /**
     * The Logger
     */
    class log4cpp::Category& _logger;

    /**
     * Service Name
     */    
    std::string _serviceName;

    /**
     * Log File Name
     */    
    std::string _logFileName;
    /**
     * Is LogFileName Set
     */    
    bool _logFileNameSet;

    /**
     * Log Priority
     */    
    std::string _priority;
    /**
     * Is Priority Set
     */    
    bool _prioritySet;
    
    /**
     * Use Rolling
     */    
    bool _rollFile;
};   


} // End namespace generator
} // End namespace config
} // End namespace glite


#endif //GLITE_DATA_CONFIG_SERVICE_CONFIG_GENERATOR_LOGGENERATOR_HXX_
