/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Conf Service ConfigGenerator : Param.hxx
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id:  $
 *  Release: $Name:  $
 *
 *  Revision history:
 *  $Log: $
 *  
 */
 
#ifndef GLITE_DATA_CONFIG_SERVICE_CONFIG_GENERATOR_PARAM_HXX_ 
#define GLITE_DATA_CONFIG_SERVICE_CONFIG_GENERATOR_PARAM_HXX_ 

#include <string>


namespace glite    {
namespace config   {
namespace generator{

class Param{
public:

	typedef enum{
		LEVEL_NORMAL = 0,
		LEVEL_ADVANCED,
		LEVEL_EXPERT,
	} LevelType;
	
    /**
     * Constructor
     */
    Param(const char * name):_name(name),_type("string"),_mandatory(false),
                             _fixed(false),_level(LEVEL_NORMAL),_include(false){}

    /**
     * Returns Param's Name
     */
    const char * getName() const {return _name.c_str();}
    
    /**
     * Returns Param's Type
     */
    const char * getType() const {return _type.c_str();}
    /**
     * Set Param's Type
     */
    void setType(const char * type) {_type = type;}

    /**
     * Returns Param's Description
     */
    const char * getDescription() const {return _description.c_str();}
    /**
     * Set Param's Description
     */
    void setDescription(const char * description) {_description = description;}

    /**
     * Returns Param's Mandatory Flag
     */
    bool getMandatory() const {return _mandatory;}
    /**
     * Set Param's Mandatory Flag
     */
    void setMandatory(bool mandatory) {_mandatory = mandatory;}

	/**
     * Returns Param's Fixed Flag
     */
    bool getFixed() const {return _fixed;}
    /**
     * Set Param's Fixed Flag
     */
    void setFixed(bool fixed) {_fixed = fixed;}

    /**
     * Returns Param's Advanced Level Flag
     */
    LevelType getLevel() const {return _level;}
    /**
     * Set Param's Advanced Level Flag
     */
    void setLevel(LevelType level) {_level = level;}
    
    /**
     * Returns Param's Value
     */
    const char * getValue() const {return _value.c_str();}
    /**
     * Set Param's Value
     */
    void setValue(const char * value) {_value = value;}
    
    /**
     * Returns Param's Include Flag
     */
    bool getInclude() const {return _include;}
    /**
     * Set Param's Include Flag
     */
    void setInclude(bool include) {_include = include;}
    
private: 
    
    /**
     * Param's Name
     */
    std::string _name;

    /**
     * Param's Type
     */
    std::string _type;

    /**
     * Param's Description
     */
    std::string _description;
    
    /**
     * Param's Mandatory Flag
     */
    bool _mandatory;

    /**
     * Param's Fixed Flag
     */
    bool _fixed;

    /**
     * Param's Advanced Flag
     */
    LevelType _level;
    
    /**
     * Param's Value
     */
    std::string _value;
    
    /**
     * Param's Include Flag
     */
    bool _include;
};   


} // End namespace generator
} // End namespace config
} // End namespace glite


#endif //GLITE_DATA_CONFIG_SERVICE_CONFIG_GENERATOR_PARAM_HXX_
