/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Conf Service ConfigGenerator : PropertyInputHandler.hxx
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: PropertyInputHandler.hxx,v 1.2 2007/12/19 11:35:24 ptedesco Exp $
 *  Release: $Name:  $
 *
 *  Revision history:
 *  $Log: PropertyInputHandler.hxx,v $
 *  Revision 1.2  2007/12/19 11:35:24  ptedesco
 *  logs and build files cleanup
 *
 *  Revision 1.1  2005/08/05 15:24:59  badino
 *  Improve config generator
 *
 *  
 */
 
#ifndef GLITE_DATA_CONFIG_SERVICE_CONFIG_GENERATOR_PROPERTYINPUTHANDLER_HXX_ 
#define GLITE_DATA_CONFIG_SERVICE_CONFIG_GENERATOR_PROPERTYINPUTHANDLER_HXX_ 

#include "InputHandler.hxx"
#include <string>

namespace log4cpp{
    class Category;
}

namespace glite    {
namespace config   {
namespace generator{

class PropertyInputHandler : public InputHandler{
public:

    /**
     * Comstructor
     */
    PropertyInputHandler(const char* key_value);

    /**
     * Get the Configuration Values for the Service
     */
    virtual int getValues(Service * service);
    
    /**
     * Get the Logging Configuration Values for the Service
     */
    virtual int getLogValues(Service * service, LogGenerator * log);

private:

    /**
     * Parse Property Key Value Pair
     */
    int parseProperty(const char * key_value);

    /**
     * Set a Service Configuration Property
     */
    int setProperty(Service * service);

    /**
     * Set a Log Configuration Property
     */
    int setLogProperty(Service * service, LogGenerator * log);
 
private:

    /**
     * The Logger
     */
    class log4cpp::Category& _logger;
    
    /**
     * The Property Key
     */
    std::string _key;

    /**
     * The Property Value
     */
    std::string _value;
};


} // End namespace generator
} // End namespace config
} // End namespace glite


#endif //GLITE_DATA_CONFIG_SERVICE_CONFIG_GENERATOR_PROPERTYINPUTHANDLER_HXX_
