/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Conf Service ConfigGenerator : Service.hxx
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id:  $
 *  Release: $Name:  $
 *
 *  Revision history:
 *  $Log: $
 *  
 */
 
#ifndef GLITE_DATA_CONFIG_SERVICE_CONFIG_GENERATOR_SERVICE_HXX_ 
#define GLITE_DATA_CONFIG_SERVICE_CONFIG_GENERATOR_SERVICE_HXX_

#include "Component.hxx"
#include <list>
#include <cstdlib>
#include <cstring>

// forward declarations
namespace log4cpp{
    class Category;
}

namespace glite{
    namespace config{
        namespace xmlutils{
            class Doc;
            class XPathContext;
            class XmlFileWriter;
        }
    }
}

namespace glite    {
namespace config   {
namespace generator{

class Service{
public:

    typedef std::list<Component *> Components;
    
    /**
     * Constructor
     */
    Service();

    /**
     * Destructor
     */
    ~Service();

    /**
     * Return the Service Components
     */
    const Components& getComponents() const {return _components;}
   
    /**
     * Return Service Name
     */
    const char * getName() const {return _name.c_str();}
    
    /**
     * Parse the Configuration Template for the given service
     * @param svc_configfile [IN] the Service Configuration File
     * @return 0 if success, -1 otherwise
     */
    int parse(const char * svc_configfile);

    /**
     * Generate the Configuration for the given service
     * @param out_name [IN] the Output File Name. If 0, the default name will be
     * used 
     * @return 0 if success, -1 otherwise
     */
    int generate(const char * out_name);
    
private:

    /**
     * Load Components from templaate Configuration File
     */
    int loadComponents(const char * svc_configfile);
      
    /**
     * Load Single Component
     */
    Component * loadComponent(
        class glite::config::xmlutils::Doc&             doc,
        class glite::config::xmlutils::XPathContext&    context,
        const std::string&                              componentXPath,
        const std::string&                              componentName);
 
    /**
     * Load Parameters
     */                     
    void loadParams(
        class glite::config::xmlutils::Doc&             doc,
        class glite::config::xmlutils::XPathContext&    context,
        const std::string&                              componentXPath,
        const std::string&                              phase,
        Component::Params&                              params); 
    
    /**
     * Serialize Components
     */                     
    int writeComponents(const std::string outputFilePath);
    
    /**
     * Serialize Parameters
     */                     
    int writeParams(
        class glite::config::xmlutils::XmlFileWriter&   writer,
        const std::string&                              phase,
        const Component::Params&                        params);

 
private: 

    /**
     * The Logger
     */
    class log4cpp::Category& _logger;
    
    /**
     * Service Name
     */
    std::string _name;    

    /**
     * Components
     */
    Components _components;
};   


} // End namespace generator
} // End namespace config
} // End namespace glite


#endif //GLITE_DATA_CONFIG_SERVICE_CONFIG_GENERATOR_SERVICE_HXX_
