/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004-2008.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  log-message.cxx
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: log-message.cxx,v 1.1 2008/06/12 14:23:53 ptedesco Exp $
 *  Release: $Name:  $
 *
 */

#include "log-message.hxx"
#include <fcntl.h>
#include <unistd.h>

/**
 * log_message
 * log a message to a file named '/tmp/<name>-svc-conf-debug.log'; to be used 
 * when the logging library is possibly not initialized
 * @param log_file_name [IN] the <name> part of the log file path
 * @param severity_string [IN] DEBUG,INFO,...
 * @param msg [IN] the log message
 */
void glite::config::log_message(
    const std::string&  log_file_name,
    const std::string&  severity_string,
    const char *        msg){
    std::string name = log_file_name;
    if(name.empty()){
        name = "glite-data-config-service";
    }
    std::string logname = (std::string)"/tmp/" + name + "-svc-conf-debug.log";
    int fh = open(logname.c_str(),O_WRONLY | O_CREAT | O_APPEND, 0644);
    if(-1 != fh){
        time_t t;
        time(&t);
        struct tm *ttm = localtime(&t);
        char tmpbuf[32];
        strftime(tmpbuf, 32,"[%Y-%m-%d %H:%M:%S]", ttm);
        std::string log_msg = (std::string)tmpbuf + " " + severity_string + " " + name + " - " + msg + "\n";
        write(fh,log_msg.c_str(), log_msg.length());
        close(fh);
    }
}




