/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  GLite Data Config Service libxml helpers
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: xpath.hxx,v 1.2 2008/01/24 08:43:44 ptedesco Exp $
 *  Release: $Name:  $
 *
 */

#ifndef GLITE_DATA_CONFIG_XMLUTILS_XPATH_HXX_
#define GLITE_DATA_CONFIG_XMLUTILS_XPATH_HXX_

#include "base-utils.hxx"
#include <libxml/xpath.h>

#   if defined(LIBXML_XPATH_ENABLED) && defined(LIBXML_SAX1_ENABLED)

namespace glite{
namespace config{
namespace xmlutils{

/**
 * XPathContext
 */
class XPathContext : public XmlWrapper<xmlXPathContext>{
public:
    /**
     * Constructor
     * @param doc [IN] the xml document
     */
    XPathContext(Doc& doc) : XmlWrapper<xmlXPathContext>(xmlXPathNewContext(doc.get()),xmlXPathFreeContext){
        if (0 == m_ptr){
            throw XmlConfigurationException("Could not create XPath evaluation context.");
        }
    }
    /**
     * Destructor
     */
    virtual ~XPathContext(){}
private:
    XPathContext();
};

/**
 * XPathObject
 */
class XPathObject : public XmlWrapper<xmlXPathObject>{
public:
    /**
     * Constructor.
     * @param context [IN] an XPathContext object
     * @param expression [IN] the xpath expression
     * NOTE: if a previous XPathObject has been instantiated and a second one 
     * is created the library exits.
     */
    XPathObject(XPathContext& context,const xmlChar* expression) : 
        XmlWrapper<xmlXPathObject>(xmlXPathEvalExpression(expression,context.get()),xmlXPathFreeObject){
        if (0 == m_ptr){
            throw XmlConfigurationException("Could not evaluate XPath expression.");
        }
    }

    /**
     * Constructor.
     * @param doc [IN] the xml document
     * @param expression [IN] the xpath expression
     */
    XPathObject(Doc& doc,const xmlChar* expression) : 
        XmlWrapper<xmlXPathObject>(xmlXPathEvalExpression(expression,XPathContext(doc).get()),xmlXPathFreeObject){
        if (0 == m_ptr){
            CONFIGURATION_EXCEPTION("Could not evaluate XPath expression '" << (char*)expression << "'");
        }
    }
    /**
     * Destructor
     */
    virtual ~XPathObject(){}
    /**
     * length
     * return number of elements
     */
    int length(){
        if (0 == m_ptr->nodesetval){
            return 0;
        }
        return m_ptr->nodesetval->nodeNr;
    }
    /**
     * @return true if no objects found
     */
    bool isEmpty(){    
        return xmlXPathNodeSetIsEmpty(m_ptr->nodesetval);
    }
private:
    XPathObject();
};

    
} // namespace xmlutils
} // namespace config
} // namespace glite

#   else
#       error "libxml2 compiled without XPath support"
#   endif

#endif // GLITE_DATA_CONFIG_XMLUTILS_XPATH_HXX_
