/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004-2008.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  ConfigServiceTest
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: ConfigServiceTest.cxx,v 1.3 2008/11/14 15:10:50 ptedesco Exp $
 *  Release: $Name:  $
 *
 */

#include <cppunit/extensions/TestFactoryRegistry.h>
#include <cppunit/ui/text/TestRunner.h>
#include <cppunit/CompilerOutputter.h>
#include <iostream>

/**
 * suite
 * create test suite
 */
CppUnit::Test * suite() {
    CppUnit::TestFactoryRegistry& registry = CppUnit::TestFactoryRegistry::getRegistry();
    CppUnit::TestFactoryRegistry& sysLogValidatorTestCase  = CppUnit::TestFactoryRegistry::getRegistry("SysLogValidatorTestCase");
    CppUnit::TestFactoryRegistry& stringConverterTestCase  = CppUnit::TestFactoryRegistry::getRegistry("StringConverterTestCase");
    CppUnit::TestFactoryRegistry& loggerTestCase           = CppUnit::TestFactoryRegistry::getRegistry("LoggerTestCase");
    
    registry.registerFactory(&sysLogValidatorTestCase);
    registry.registerFactory(&stringConverterTestCase);
    registry.registerFactory(&loggerTestCase);

    return registry.makeTest();
}


/**
 * main
 */
int main(int /*argc*/, char* /*argv*/[]) {
    CppUnit::TextUi::TestRunner runner;
    runner.addTest(suite());   // Add the suite to the test runner
    // Change the default outputter to a compiler error format outputter
    // The test runner owns the new outputter.
    runner.setOutputter( 
        CppUnit::CompilerOutputter::defaultOutputter(&runner.result(),std::cerr));
    // Run the test
    bool wasSucessful = runner.run();
    return wasSucessful ? 0 : 1;
}
