/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004-2008.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SysLogValidatorTestCase
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: SysLogValidatorTestCase.cxx,v 1.2 2008/07/02 15:19:43 ptedesco Exp $
 *  Release: $Name:  $
 *
 */

#include <cppunit/TestCase.h>
#include <cppunit/extensions/HelperMacros.h>
#include <SysLogValidator.hxx> 
#include <sstream>

#define CHECK_VALUE(value,expected) \
    if (value != expected){ \
        std::stringstream err; \
        err << "Got '" << value << "', expected '" << expected << "'"; \
        CPPUNIT_FAIL(err.str().c_str()); \
    }

#define VALIDATE_EVENT_NAME(event_name,expected) \
    { \
        std::string validated_event_name; \
        SysLogValidator::instance().validate_event_name(event_name,validated_event_name); \
        CHECK_VALUE(validated_event_name,expected); \
    }

#define VALIDATE_NAME(name,expected) \
    { \
        std::string validated_name = SysLogValidator::instance().validate_name(name); \
        CHECK_VALUE(validated_name,expected); \
    }

#define VALIDATE_VALUE(value,expected) \
    { \
        std::string validated_value = SysLogValidator::instance().validate_value(value); \
        CHECK_VALUE(validated_value,expected); \
    }
             
using namespace glite::config;

/**
 * SysLogValidatorTestCase
 */
class SysLogValidatorTestCase : public CppUnit::TestCase{
public:
protected:
    
    // declare tests
    CPPUNIT_TEST_SUITE( SysLogValidatorTestCase);
        CPPUNIT_TEST( test_validate_event_name_01 );
        CPPUNIT_TEST( test_validate_event_name_02 );
        CPPUNIT_TEST( test_validate_event_name_03 );
        CPPUNIT_TEST( test_validate_event_name_04 );
        CPPUNIT_TEST( test_validate_event_name_05 );
    
        CPPUNIT_TEST( test_validate_name_01 );
        CPPUNIT_TEST( test_validate_name_02 );
        CPPUNIT_TEST( test_validate_name_03 );
        CPPUNIT_TEST( test_validate_name_04 );
        CPPUNIT_TEST( test_validate_name_05 );

        CPPUNIT_TEST( test_validate_value_01 );
        CPPUNIT_TEST( test_validate_value_02 );
        CPPUNIT_TEST( test_validate_value_03 );
        CPPUNIT_TEST( test_validate_value_04 );
        CPPUNIT_TEST( test_validate_value_05 );
                
    CPPUNIT_TEST_SUITE_END();

    // event name validation
    void test_validate_event_name_01 (){
        VALIDATE_EVENT_NAME("test","test");
    }

    void test_validate_event_name_02 (){
        VALIDATE_EVENT_NAME("test1.test2","test1.test2");
    }

    void test_validate_event_name_03 (){
        VALIDATE_EVENT_NAME("  test1.test2","test1.test2");
    }

    void test_validate_event_name_04 (){
        VALIDATE_EVENT_NAME("1test1.test2","test1.test2");
    }

    void test_validate_event_name_05 (){
        VALIDATE_EVENT_NAME("test_1.test_2.test_3  test_4","test_1.test_2.test_3");
    }
    
    // name validation
    void test_validate_name_01 (){
        VALIDATE_NAME("test","test");
    }

    void test_validate_name_02 (){
        VALIDATE_NAME("test1","test1");
    }

    void test_validate_name_03 (){
        VALIDATE_NAME("  test","test");
    }

    void test_validate_name_04 (){
        VALIDATE_NAME("test  ","test");
    }

    void test_validate_name_05 (){
        VALIDATE_NAME("test.test","test");
    }
        
    // value validation
    void test_validate_value_01 (){
        VALIDATE_VALUE("test","test");
    }

    void test_validate_value_02 (){
        VALIDATE_VALUE("\"test\"","\\\"test\\\"");
    }

    void test_validate_value_03 (){
        VALIDATE_VALUE("test\\ test","test\\\\ test");
    }

    void test_validate_value_04 (){
        VALIDATE_VALUE("test%test","test\\%test");
    }

    void test_validate_value_05 (){
        VALIDATE_VALUE("test\ntest","test%0atest");
    }

};

CPPUNIT_TEST_SUITE_NAMED_REGISTRATION( SysLogValidatorTestCase, "SysLogValidatorTestCase" );


