/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *      test-module.cxx
 *
 *      Authors: Paolo Badino <paolo.badino@cern.ch>
 *      Version info: $Id: test-module.cxx,v 1.3 2007/12/19 11:35:24 ptedesco Exp $
 *      Release: $Name:  $
 *
 *      Revision history:
 *      $Log: test-module.cxx,v $
 *      Revision 1.3  2007/12/19 11:35:24  ptedesco
 *      logs and build files cleanup
 *
 *      Revision 1.2  2004/08/30 12:48:10  badino
 *      Add ParamValue Class
 *      Set Version to 0.1.0
 *
 *      Revision 1.1.1.1  2004/08/18 15:52:41  badino
 *      Import of Module GLite Data config Service v.0.0
 *
 *
 */

#include "test-module.hxx"
#include "glite/data/config/service/ParamValue.hxx"

#include "log4cpp/Category.hh"
using namespace log4cpp;
using namespace glite::config;

extern "C" {

/**
 * Create Component instance
 */
ComponentConfiguration * create_glite_component(){
    return TestComponent::instance();
}

/**
 * Destroy Component instance
 */
void destroy_glite_component(ComponentConfiguration * component){
    TestComponent::finalize();
}

} // End extern "C"

TestComponent* TestComponent::_instance = 0;

/**
 * Return Singleton Instance
 */
TestComponent * TestComponent::instance(){
    if(0 == _instance){
        _instance = new TestComponent();
    }
    return _instance;
}

/**
 * Finalize Singleton Instance
 */
void TestComponent::finalize(){
    if(0 != _instance){
        delete _instance;
    }
}

TestComponent::TestComponent():ComponentConfiguration("test-component"),
   _logger(Category::getInstance("test-component")){
}

/**
 * Initialize the Component
 */
int TestComponent::init(const Params& params){
    
    Params::const_iterator it;
    for(it = params.begin(); it != params.end(); it++){
        ParamValue * val = dynamic_cast<ParamValue *>((*it).second);
        _logger.debug("Init Parameter %s value is %s",(*it).first.c_str(),val->getValue().c_str());
    }
    _logger.info("initialization completed");
    
    return 0;
}

/**
 * Configure the Component
 */
int TestComponent::config(const Params& params){
    
    Params::const_iterator it;
    for(it = params.begin(); it != params.end(); it++){
        ParamValue * val = dynamic_cast<ParamValue *>((*it).second);
        _logger.debug("Config Parameter %s value is %s",(*it).first.c_str(),val->getValue().c_str());
    }
    _logger.info("configuration completed");
    
    return 0;
}

/**
 * Start the Component
 */
int TestComponent::start(){
    
    _logger.debug("Component Started");
    return 0;
}

/**
 * stop the Component
 */
int TestComponent::stop(){
    
    _logger.debug("Component Stopped");
    return 0;
}

void glite_doSomethingElse(const char * requestor, const char * str);
 
/**
 * Do Something
 */
void TestComponent::doSomething(const char * requestor, const char * str){
    
    _logger.debug("Debug Message");
    _logger.info("%s request me to do %s",requestor, str);
    
    glite_doSomethingElse("test-component","My stuff");
}

/**
 * Finalize the Component
 */
int TestComponent::fini(){
    
    _logger.info("finalization completed");
    return 0;
}
