/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *      test-module.cxx
 *
 *      Authors: Paolo Badino <paolo.badino@cern.ch>
 *      Version info: $Id: test-module.hxx,v 1.2 2008/01/24 08:43:44 ptedesco Exp $
 *      Release: $Name:  $
 *
 *      Revision history:
 *      $Log: test-module.hxx,v $
 *      Revision 1.2  2008/01/24 08:43:44  ptedesco
 *      Fixed bug 28272
 *
 *      Revision 1.1.1.1  2004/08/18 15:52:41  badino
 *      Import of Module GLite Data config Service v.0.0
 *
 *
 */

#ifndef TEST_MODULE_HXX
#define TEST_MODULE_HXX

#include "glite/data/config/service/ComponentConfiguration.hxx"

namespace log4cpp{
    class Category;
}

class TestComponent: public glite::config::ComponentConfiguration {
public:
    /**
     * Initialize the Component
     */
    virtual int init(const Params& params);

    /**
     * Configure the Component
     */
    virtual int config(const Params& params);

    /**
     * Start the Component
     */
    virtual int start();
    
    /**
     * Stop the Component
     */
    virtual int stop();
    
    /**
     * Finailize the Component
     */
    virtual int fini();
    
    /**
     * Do Something
     */
    void doSomething(const char * requestor, const char * str);
    
    /**
     * Return Singleton Instance
     */
    static TestComponent * instance();
    
    /**
     * Finalize Singleton Instance
     */
    static void finalize();
    
protected:
    /**
     * Constructor
     */
    TestComponent();
    
    /**
     * Destructor
     */
    virtual ~TestComponent(){}
    
private:

    /**
     * Singleton Instance
     */
    static TestComponent * _instance;
    
    /**
     * The Logger
     */
    class log4cpp::Category& _logger;
};

#endif //TEST_MODULE_HXX
